// Intel's UPnP .NET Framework Control Point Stack, Core Module
// Intel StackBuilder Build#1.0.1868.18043

using System;
using Intel.UPNP;
using TemperatureControlPoint;

namespace TemperatureControlPoint
{
	/// <summary>
	/// Summary description for Main.
	/// </summary>
	public class SampleDeviceMain
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
        /// 

        private static CpTemperatureService cptemperatureService;
        private static CpLedsService cpledService;
        private static CpMusicService cpmusicService;
        private static CpConfigService cpconfigService;

        public SampleDeviceMain()
        {
			System.Console.WriteLine("Intel's UPnP .NET Framework Stack");
			System.Console.WriteLine("Intel StackBuilder Build#Intel StackBuilder Build#1.0.1868.18043");
			
			SampleDiscovery disco = new SampleDiscovery();
			disco.OnAddedDevice += new SampleDiscovery.DiscoveryHandler(AddSink);
			disco.OnRemovedDevice += new SampleDiscovery.DiscoveryHandler(RemoveSink);
			
			disco.Start();
		}

		
		private static void AddSink(SampleDiscovery sender, UPnPDevice d)
		{
			Console.WriteLine("Added Device: " + d.FriendlyName);
			
			// To interace with a service, instantiate the appropriate wrapper class on the appropriate service
			// Traverse the device heirarchy to the correct device, and invoke 'GetServices', passing in the static field 'SERVICE_NAME'
			// of the appropriate wrapper class. This method returns an array of all services with this service type. For most purposes,
			// there will only be one service, in which case you can use array index 0.
			// Save a reference to this instance of the wrapper class for later use.
			//CpTemperatureService TemperatureService
            if (d.FriendlyName.Equals("TemperatureDevice"))
            {
                cptemperatureService = new CpTemperatureService(d.GetServices(CpTemperatureService.SERVICE_NAME)[0]);
                cptemperatureService._subscribe(300);
                System.Console.WriteLine(" TemperatureDevice added");
            }

            if(d.FriendlyName.Equals("LedsDevice"))
            {
               
                cpledService = new CpLedsService(d.GetServices(CpLedsService.SERVICE_NAME)[0]);
                cpledService._subscribe(300);
                System.Console.WriteLine(" LedsDevice added");
               
            }


            if (d.FriendlyName.Equals("MusicDevice"))
            {
                cpmusicService = new CpMusicService(d.GetServices(CpMusicService.SERVICE_NAME)[0]);
                cpmusicService._subscribe(300);
                System.Console.WriteLine(" MusicDevice added");
            }


            if (d.FriendlyName.Equals("ConfigDevice"))
            {
                cpconfigService = new CpConfigService(d.GetServices(CpConfigService.SERVICE_NAME)[0]);
                cpconfigService._subscribe(300);
                System.Console.WriteLine(" ConfigDevice added");
            }


            
			// To subscribe to Events, call the '_subscribe' method of the wrapper class. The only parameter is
			// the duration of the event. A good value is 300 seconds.
          
           
			// The wrapper class exposes all the evented state variables through events in the form 'OnStateVariable_xx', where xx is the variable name.
			
			// The wrapper class exposes methods in two formats. Asyncronous and Syncronous. The Async method calls are exposed simply
			// by the name of the method. The Syncronous version is the same, except with the word, 'Sync_' prepended to the name.
			// Asyncronous responses to th async method calls are dispatched through the event in the format, 'OnResult_x' where x is the method name.
			
			// Note: All arguments are automatically type checked. Allowed Values are abstracted through enumerations, that are defined in the wrapper class.
			// To access the list of allowed values or ranges for a given device, refer to the property 'Values_XXX' for a list of the allowed values for a
			// given state variable. Similarly, refer to the properties 'HasMaximum_XXX', 'HasMinimum_XXX', 'Maximum_XXX', and 'Minimum_XXX' where XXX is the variable name, for the Max/Min values.
			
			// To determine if a given service implements a particular StateVariable or Method, use the properties, 'HasStateVariableXXX' and 'HasActionXXX' where XXX is the method/variable name.
		}
		private static void RemoveSink(SampleDiscovery sender, UPnPDevice d)
		{
			Console.WriteLine("Removed Device: " + d.FriendlyName);
		}


        public  int  getTemperatureAmbiante()
        {
            Console.WriteLine("TemperatureService_getTemperatureAmbiante(" + ")");
            int ret = cptemperatureService.Sync_getTemperatureAmbiante();
            System.Console.WriteLine("Temperature ambiante = " + ret);
            return ret;

         
        }

        public  int getTemperatureEau()
        {
            Console.WriteLine("TemperatureService_getTemperatureEau(" + ")");
            int ret = cptemperatureService.Sync_getTemperatureEau();
            System.Console.WriteLine("Temperature eau  = " +ret);
            return ret;

        }

        public void switchOnBlueLeds()
        {
            Console.WriteLine("LedService_on");
            cpledService.Sync_OnBlueLeds();
            
        }
        public void switchOnRedsLeds()
        {
            Console.WriteLine("LedService_on");
            cpledService.Sync_OnRedLeds();

        }
        public void switchOnWhiteLeds()
        {
            Console.WriteLine("LedService_on");
            cpledService.Sync_OnWhiteLeds();

        }

        public  void switchOffBlueLeds()
        {
            Console.WriteLine("LedService_off");
            cpledService.Sync_OffBlueLeds();
           
        }
        public  void switchOffRedLeds()
        {
            Console.WriteLine("LedService_off");
            cpledService.Sync_OffRedLeds();

        }
        public  void switchOffWhiteLeds()
        {
            Console.WriteLine("LedService_off");
            cpledService.Sync_OffWhiteLeds();

        }

        public void play()
        {
            Console.WriteLine("play");
            cpmusicService.Sync_play();
        }

        public void stop()
        {
            Console.WriteLine("stop");
            cpmusicService.Sync_stop();
        }

        public void assignAddress(String address)
        {
            Console.WriteLine("assignAddress ");
            cpmusicService.Sync_assignAddress(address);
        }


        public void configure(String conf)
        {
            Console.WriteLine("configure  ");
            cpconfigService.Sync_configure(conf);
        }

        
	}
}

