using System;
using System.Collections;
using System.Threading;
using Intel.Utilities;
using Intel.UPNP;

namespace TemperatureControlPoint
{
    /// <summary>
    /// Transparent ClientSide UPnP Service
    /// </summary>
    public class CpLedService
    {
       private Hashtable UnspecifiedTable = Hashtable.Synchronized(new Hashtable());
       internal UPnPService _S;

       public UPnPService GetUPnPService()
       {
            return(_S);
       }
       public static string SERVICE_NAME = "urn:schemas-upnp-org:service:LedService:";
       public double VERSION
       {
           get
           {
               return(double.Parse(_S.Version));
           }
       }

       public delegate void StateVariableModifiedHandler_Status(CpLedService sender, System.Boolean NewValue);
       private WeakEvent OnStateVariable_Status_Event = new WeakEvent();
       public event StateVariableModifiedHandler_Status OnStateVariable_Status
       {
			add{OnStateVariable_Status_Event.Register(value);}
			remove{OnStateVariable_Status_Event.UnRegister(value);}
       }
       protected void Status_ModifiedSink(UPnPStateVariable Var, object NewValue)
       {
            OnStateVariable_Status_Event.Fire(this, Status);
       }
       public delegate void SubscribeHandler(CpLedService sender, bool Success);
       public event SubscribeHandler OnSubscribe;
       public delegate void Delegate_OnResult_GetStatus(CpLedService sender, System.Boolean ReturnValue, UPnPInvokeException e, object _Tag);
       private WeakEvent OnResult_GetStatus_Event = new WeakEvent();
       public event Delegate_OnResult_GetStatus OnResult_GetStatus
       {
			add{OnResult_GetStatus_Event.Register(value);}
			remove{OnResult_GetStatus_Event.UnRegister(value);}
       }
       public delegate void Delegate_OnResult_Off(CpLedService sender, UPnPInvokeException e, object _Tag);
       private WeakEvent OnResult_Off_Event = new WeakEvent();
       public event Delegate_OnResult_Off OnResult_Off
       {
			add{OnResult_Off_Event.Register(value);}
			remove{OnResult_Off_Event.UnRegister(value);}
       }
       public delegate void Delegate_OnResult_On(CpLedService sender, UPnPInvokeException e, object _Tag);
       private WeakEvent OnResult_On_Event = new WeakEvent();
       public event Delegate_OnResult_On OnResult_On
       {
			add{OnResult_On_Event.Register(value);}
			remove{OnResult_On_Event.UnRegister(value);}
       }
       public delegate void Delegate_OnResult_SetStatus(CpLedService sender, System.Boolean newValue, UPnPInvokeException e, object _Tag);
       private WeakEvent OnResult_SetStatus_Event = new WeakEvent();
       public event Delegate_OnResult_SetStatus OnResult_SetStatus
       {
			add{OnResult_SetStatus_Event.Register(value);}
			remove{OnResult_SetStatus_Event.UnRegister(value);}
       }

        public CpLedService(UPnPService s)
        {
            _S = s;
            _S.OnSubscribe += new UPnPService.UPnPEventSubscribeHandler(_subscribe_sink);
            if(HasStateVariable_Status) _S.GetStateVariableObject("Status").OnModified += new UPnPStateVariable.ModifiedHandler(Status_ModifiedSink);
        }
        public void Dispose()
        {
            _S.OnSubscribe -= new UPnPService.UPnPEventSubscribeHandler(_subscribe_sink);
            OnSubscribe = null;
            if(HasStateVariable_Status) _S.GetStateVariableObject("Status").OnModified -= new UPnPStateVariable.ModifiedHandler(Status_ModifiedSink);
        }
        public void _subscribe(int Timeout)
        {
            _S.Subscribe(Timeout, null);
        }
        protected void _subscribe_sink(UPnPService sender, bool OK)
        {
            if(OnSubscribe!=null)
            {
                OnSubscribe(this, OK);
            }
        }
        public void SetUnspecifiedValue(string EnumType, string val)
        {
            string hash = Thread.CurrentThread.GetHashCode().ToString() + ":" + EnumType;
            UnspecifiedTable[hash] = val;
        }
        public string GetUnspecifiedValue(string EnumType)
        {
            string hash = Thread.CurrentThread.GetHashCode().ToString() + ":" + EnumType;
            if(UnspecifiedTable.ContainsKey(hash)==false)
            {
               return("");
            }
            string RetVal = (string)UnspecifiedTable[hash];
            return(RetVal);
        }
        public System.Boolean Status
        {
            get
            {
               return((System.Boolean)_S.GetStateVariable("Status"));
            }
        }
        public bool HasStateVariable_Status
        {
            get
            {
               if(_S.GetStateVariableObject("Status")==null)
               {
                   return(false);
               }
               else
               {
                   return(true);
               }
            }
        }
        public bool HasAction_GetStatus
        {
            get
            {
               if(_S.GetAction("GetStatus")==null)
               {
                   return(false);
               }
               else
               {
                   return(true);
               }
            }
        }
        public bool HasAction_Off
        {
            get
            {
               if(_S.GetAction("Off")==null)
               {
                   return(false);
               }
               else
               {
                   return(true);
               }
            }
        }
        public bool HasAction_On
        {
            get
            {
               if(_S.GetAction("On")==null)
               {
                   return(false);
               }
               else
               {
                   return(true);
               }
            }
        }
        public bool HasAction_SetStatus
        {
            get
            {
               if(_S.GetAction("SetStatus")==null)
               {
                   return(false);
               }
               else
               {
                   return(true);
               }
            }
        }
        public System.Boolean Sync_GetStatus()
        {
           UPnPArgument[] args = new UPnPArgument[0];
           object RetVal = null;
           RetVal = _S.InvokeSync("GetStatus", args);
           return((System.Boolean)RetVal);
        }
        public void GetStatus()
        {
            GetStatus(null, null);
        }
        public void GetStatus(object _Tag, Delegate_OnResult_GetStatus _Callback)
        {
           UPnPArgument[] args = new UPnPArgument[0];
           _S.InvokeAsync("GetStatus", args, new object[2]{_Tag,_Callback},new UPnPService.UPnPServiceInvokeHandler(Sink_GetStatus), new UPnPService.UPnPServiceInvokeErrorHandler(Error_Sink_GetStatus));
        }
        private void Sink_GetStatus(UPnPService sender, string MethodName, UPnPArgument[] Args, object RetVal, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_GetStatus)StateInfo[1])(this, (System.Boolean)RetVal, null, StateInfo[0]);
            }
            else
            {
                OnResult_GetStatus_Event.Fire(this, (System.Boolean)RetVal, null, StateInfo[0]);
            }
        }
        private void Error_Sink_GetStatus(UPnPService sender, string MethodName, UPnPArgument[] Args, UPnPInvokeException e, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_GetStatus)StateInfo[1])(this, (System.Boolean)UPnPService.CreateObjectInstance(typeof(System.Boolean),null), e, StateInfo[0]);
            }
            else
            {
                OnResult_GetStatus_Event.Fire(this, (System.Boolean)UPnPService.CreateObjectInstance(typeof(System.Boolean),null), e, StateInfo[0]);
            }
        }
        public void Sync_Off()
        {
           UPnPArgument[] args = new UPnPArgument[0];
            _S.InvokeSync("Off", args);
            return;
        }
        public void Off()
        {
            Off(null, null);
        }
        public void Off(object _Tag, Delegate_OnResult_Off _Callback)
        {
           UPnPArgument[] args = new UPnPArgument[0];
           _S.InvokeAsync("Off", args, new object[2]{_Tag,_Callback},new UPnPService.UPnPServiceInvokeHandler(Sink_Off), new UPnPService.UPnPServiceInvokeErrorHandler(Error_Sink_Off));
        }
        private void Sink_Off(UPnPService sender, string MethodName, UPnPArgument[] Args, object RetVal, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_Off)StateInfo[1])(this, null, StateInfo[0]);
            }
            else
            {
                OnResult_Off_Event.Fire(this, null, StateInfo[0]);
            }
        }
        private void Error_Sink_Off(UPnPService sender, string MethodName, UPnPArgument[] Args, UPnPInvokeException e, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_Off)StateInfo[1])(this, e, StateInfo[0]);
            }
            else
            {
                OnResult_Off_Event.Fire(this, e, StateInfo[0]);
            }
        }
        public void Sync_On()
        {
           UPnPArgument[] args = new UPnPArgument[0];
            _S.InvokeSync("On", args);
            return;
        }
        public void On()
        {
            On(null, null);
        }
        public void On(object _Tag, Delegate_OnResult_On _Callback)
        {
           UPnPArgument[] args = new UPnPArgument[0];
           _S.InvokeAsync("On", args, new object[2]{_Tag,_Callback},new UPnPService.UPnPServiceInvokeHandler(Sink_On), new UPnPService.UPnPServiceInvokeErrorHandler(Error_Sink_On));
        }
        private void Sink_On(UPnPService sender, string MethodName, UPnPArgument[] Args, object RetVal, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_On)StateInfo[1])(this, null, StateInfo[0]);
            }
            else
            {
                OnResult_On_Event.Fire(this, null, StateInfo[0]);
            }
        }
        private void Error_Sink_On(UPnPService sender, string MethodName, UPnPArgument[] Args, UPnPInvokeException e, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_On)StateInfo[1])(this, e, StateInfo[0]);
            }
            else
            {
                OnResult_On_Event.Fire(this, e, StateInfo[0]);
            }
        }
        public void Sync_SetStatus(System.Boolean newValue)
        {
           UPnPArgument[] args = new UPnPArgument[1];
           args[0] = new UPnPArgument("newValue", newValue);
            _S.InvokeSync("SetStatus", args);
            newValue = (System.Boolean) args[0].DataValue;
            return;
        }
        public void SetStatus(System.Boolean newValue)
        {
            SetStatus(newValue, null, null);
        }
        public void SetStatus(System.Boolean newValue, object _Tag, Delegate_OnResult_SetStatus _Callback)
        {
           UPnPArgument[] args = new UPnPArgument[1];
           args[0] = new UPnPArgument("newValue", newValue);
           _S.InvokeAsync("SetStatus", args, new object[2]{_Tag,_Callback},new UPnPService.UPnPServiceInvokeHandler(Sink_SetStatus), new UPnPService.UPnPServiceInvokeErrorHandler(Error_Sink_SetStatus));
        }
        private void Sink_SetStatus(UPnPService sender, string MethodName, UPnPArgument[] Args, object RetVal, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_SetStatus)StateInfo[1])(this, (System.Boolean )Args[0].DataValue, null, StateInfo[0]);
            }
            else
            {
                OnResult_SetStatus_Event.Fire(this, (System.Boolean )Args[0].DataValue, null, StateInfo[0]);
            }
        }
        private void Error_Sink_SetStatus(UPnPService sender, string MethodName, UPnPArgument[] Args, UPnPInvokeException e, object _Tag)
        {
            object[] StateInfo = (object[])_Tag;
            if(StateInfo[1]!=null)
            {
                ((Delegate_OnResult_SetStatus)StateInfo[1])(this, (System.Boolean )Args[0].DataValue, e, StateInfo[0]);
            }
            else
            {
                OnResult_SetStatus_Event.Fire(this, (System.Boolean )Args[0].DataValue, e, StateInfo[0]);
            }
        }
    }
}