// Intel's UPnP .NET Framework Control Point Stack, Core Module
// Intel StackBuilder Build#1.0.1868.18043

using System;
using Intel.UPNP;
using TemperatureControlPoint;

namespace TemperatureControlPoint
{
	/// <summary>
	/// Summary description for Main.
	/// </summary>
	class SampleDeviceMain
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
        /// 

        private static CpTemperatureService cptemperatureService;
        private static CpLedService cpledService;


        [STAThread]
        static void Main(string[] args)
		{
			System.Console.WriteLine("Intel's UPnP .NET Framework Stack");
			System.Console.WriteLine("Intel StackBuilder Build#Intel StackBuilder Build#1.0.1868.18043");
			
			SampleDiscovery disco = new SampleDiscovery();
			disco.OnAddedDevice += new SampleDiscovery.DiscoveryHandler(AddSink);
			disco.OnRemovedDevice += new SampleDiscovery.DiscoveryHandler(RemoveSink);
			
			
			disco.Start();
            bool arret = false;

            int choose_action;
            while (!arret)
            {
            System.Console.WriteLine("******************************************************");
            System.Console.WriteLine("******************* MENU *****************************");
            System.Console.WriteLine("* Choisissez l'action a executer ");
            System.Console.WriteLine("* Tapez 1 pour recuperer la temprature ambiante ");
            System.Console.WriteLine("* Tapez 2 pour recuperer la temprature de l'eau ");
            System.Console.WriteLine("* Tapez 3 pour recuperer l'tat des Leds  ");
            System.Console.WriteLine("* Tapez 4 pour changer l'tat des leds ");
            System.Console.WriteLine("* Tapez 5 pour allumer les leds ");
            System.Console.WriteLine("* Tapez 6 pour eteindre les leds ");
            System.Console.WriteLine("* Tapez toute autre chose pour quittez l'application");
            System.Console.WriteLine("******************************************************");
            Int32.TryParse(System.Console.ReadLine(), out choose_action);
            System.Console.WriteLine("Vous avez tapez :  " + choose_action);
          
                switch (choose_action)
                {
                    case 1: getTemperatureAmbiante();
                        break;
                    case 2: getTemperatureEau();
                        break;
                    case 3: getLedStatus();
                        break;
                    case 4:
                        {
                            System.Console.WriteLine("Tapez 0 pour teint et 1 pour allum ");
                            int status;
                            Int32.TryParse(System.Console.ReadLine(), out status);
                            setLedStatus(status );
                            break;
                        }
                    case 5: switchOn();
                        break;
                    case 6: switchOff();
                        break;
                    default: arret = true;
                        System.Console.WriteLine("Aurevoir !!!");
                        break;
                }
            }


          /*  getTemperatureAmbiante();
            getTemperatureEau();*/

           // System.Console.ReadLine();
           


		}
		
		private static void AddSink(SampleDiscovery sender, UPnPDevice d)
		{
			Console.WriteLine("Added Device: " + d.FriendlyName);
			
			// To interace with a service, instantiate the appropriate wrapper class on the appropriate service
			// Traverse the device heirarchy to the correct device, and invoke 'GetServices', passing in the static field 'SERVICE_NAME'
			// of the appropriate wrapper class. This method returns an array of all services with this service type. For most purposes,
			// there will only be one service, in which case you can use array index 0.
			// Save a reference to this instance of the wrapper class for later use.
			//CpTemperatureService TemperatureService
            if (d.FriendlyName.Equals("TemperatureDevice"))
            {
                cptemperatureService = new CpTemperatureService(d.GetServices(CpTemperatureService.SERVICE_NAME)[0]);
                cptemperatureService._subscribe(300);
            }

            if(d.FriendlyName.Equals("LedDevice"))
            {
               
                cpledService = new CpLedService(d.GetServices(CpLedService.SERVICE_NAME)[0]);
                cpledService._subscribe(300);
               
            }
           
			
            
			// To subscribe to Events, call the '_subscribe' method of the wrapper class. The only parameter is
			// the duration of the event. A good value is 300 seconds.
          
           
			// The wrapper class exposes all the evented state variables through events in the form 'OnStateVariable_xx', where xx is the variable name.
			
			// The wrapper class exposes methods in two formats. Asyncronous and Syncronous. The Async method calls are exposed simply
			// by the name of the method. The Syncronous version is the same, except with the word, 'Sync_' prepended to the name.
			// Asyncronous responses to th async method calls are dispatched through the event in the format, 'OnResult_x' where x is the method name.
			
			// Note: All arguments are automatically type checked. Allowed Values are abstracted through enumerations, that are defined in the wrapper class.
			// To access the list of allowed values or ranges for a given device, refer to the property 'Values_XXX' for a list of the allowed values for a
			// given state variable. Similarly, refer to the properties 'HasMaximum_XXX', 'HasMinimum_XXX', 'Maximum_XXX', and 'Minimum_XXX' where XXX is the variable name, for the Max/Min values.
			
			// To determine if a given service implements a particular StateVariable or Method, use the properties, 'HasStateVariableXXX' and 'HasActionXXX' where XXX is the method/variable name.
		}
		private static void RemoveSink(SampleDiscovery sender, UPnPDevice d)
		{
			Console.WriteLine("Removed Device: " + d.FriendlyName);
		}


        public static void  getTemperatureAmbiante()
        {
            Console.WriteLine("TemperatureService_getTemperatureAmbiante(" + ")");
            System.Console.WriteLine("Temperature ambiante = " + cptemperatureService.Sync_getTemperatureAmbiante());

         
        }

        public static void getTemperatureEau()
        {
            Console.WriteLine("TemperatureService_getTemperatureEau(" + ")");
            System.Console.WriteLine("Temperature eau  = " + cptemperatureService.Sync_getTemperatureEau());

        }

        public static void switchOn()
        {
            Console.WriteLine("LedService_on");
            cpledService.Sync_On();
        }

        public static void switchOff()
        {
            Console.WriteLine("LedService_off");
            cpledService.Sync_Off();
        }

        public static void getLedStatus()
        {
            Console.WriteLine("LedService_getLedStatus()");
            System.Console.WriteLine("Le status des leds est : " + cpledService.Sync_GetStatus());
        }

        public static void setLedStatus(int status)
        {
            Console.WriteLine("LedService_setLedStatus");
            if( status == 1)
                 cpledService.Sync_SetStatus(true);
            else
               cpledService.Sync_SetStatus(false);
        }
   
	}
}

