// Intel's UPnP .NET Framework Control Point Stack, Discovery Module
// Intel StackBuilder Build#1.0.1868.18043

using System;
using Intel.UPNP;
using Intel.Utilities;
using TemperatureControlPoint;

namespace TemperatureControlPoint
{
	/// <summary>
	/// Summary description for SampleDiscovery.
	/// </summary>
	class SampleDiscovery
	{
		private UPnPSmartControlPoint scp;
		private WeakEvent AddEvent = new WeakEvent();
		private WeakEvent RemoveEvent = new WeakEvent();
		
		public delegate void DiscoveryHandler(SampleDiscovery sender, UPnPDevice dev);
		public event DiscoveryHandler OnAddedDevice
		{
			add
			{
				AddEvent.Register(value);
			}
			remove
			{
				AddEvent.UnRegister(value);
			}
		}
		public event DiscoveryHandler OnRemovedDevice
		{
			add
			{
				RemoveEvent.Register(value);
			}
			remove
			{
				RemoveEvent.UnRegister(value);
			}
		}
		
		public SampleDiscovery()
		{
		}
		
		public void Start()
		{
			scp = new UPnPSmartControlPoint(new UPnPSmartControlPoint.DeviceHandler(OnAddSink),null,"urn:schemas-upnp-org:device:Sample:1");
			scp.OnRemovedDevice += new UPnPSmartControlPoint.DeviceHandler(OnRemoveSink);
		}
		public void ReScan()
		{
			scp.Rescan();
		}
		public void ForceDisposeDevice(UPnPDevice dev)
		{
			if(dev.ParentDevice!=null)
			{
				ForceDisposeDevice(dev.ParentDevice);
			}
			else
			{
				scp.ForceDisposeDevice(dev);
			}
		}
		
		private void OnAddSink(UPnPSmartControlPoint sender, UPnPDevice d)
		{
			AddEvent.Fire(this,d);
		}
		private void OnRemoveSink(UPnPSmartControlPoint sender, UPnPDevice d)
		{
			RemoveEvent.Fire(this,d);
		}
	}
}

